@@ -3,12 +3,13 @@ Main interface for secretsmanager service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.secretsmanager import (
+    from mypy_boto3_secretsmanager import (
         Client,
         ListSecretsPaginator,
         SecretsManagerClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,6 +17,7 @@ Usage::
     session_client: SecretsManagerClient = session.client("secretsmanager")
 
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
+    ```
 """
 from mypy_boto3_secretsmanager.client import SecretsManagerClient as Client, SecretsManagerClient
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
