@@ -3,14 +3,18 @@ Main interface for secretsmanager service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.secretsmanager import (
+
+    from mypy_boto3_secretsmanager import SecretsManagerClient
+    from mypy_boto3_secretsmanager import (
         ListSecretsPaginator,
     )
 
     client: SecretsManagerClient = boto3.client("secretsmanager")
 
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
@@ -23,12 +27,12 @@ __all__ = ("ListSecretsPaginator",)
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [ListSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [ListSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         """
